/*
 * Copyright 2009 bufferings[at]gmail.com
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package bufferings.ktr.s3unit.env;

import java.util.Locale;

import org.slim3.tester.DatastoreTester;
import org.slim3.util.ApplicationMessage;

import bufferings.ktr.s3unit.util.NoServerLibraryConfigurator;
import bufferings.ktr.s3unit.util.NoServerLoggingConfigurator;

/**
 * Environment for tests running without a server.
 * 
 * @author bufferings[at]gmail.com
 */
public class NoServerEnv implements Env {

  protected static final String API_PROXY_LOCAL =
    "com.google.appengine.tools.development.ApiProxyLocal";

  /** a tester for local data store */
  protected DatastoreTester datastoreTester;

  /** an application message bundle name */
  protected String bundleName = "application";

  /** locale */
  protected Locale locale = Locale.getDefault();

  /** {@inheritDoc} */
  public void setUp() throws Exception {
    createLibraryConfigurator().configure();
    createLoggingConfigurator().configure();
    ApplicationMessage.setBundle(bundleName, locale);

    try {
      Class.forName(API_PROXY_LOCAL);
      datastoreTester = new DatastoreTester();
      datastoreTester.setUp();
    } catch (Throwable ignore) {
    }
  }

  /** {@inheritDoc} */
  public void tearDown() throws Exception {
    if (datastoreTester != null) {
      datastoreTester.tearDown();
    }
    ApplicationMessage.clearBundle();
  }

  /**
   * Creates a logging configurator.
   * 
   * @return created logging configurator
   */
  protected NoServerLoggingConfigurator createLoggingConfigurator() {
    return new NoServerLoggingConfigurator();
  }

  /**
   * Creates a library configurator.
   * 
   * @return created library configurator
   */
  protected NoServerLibraryConfigurator createLibraryConfigurator() {
    return new NoServerLibraryConfigurator();
  }

}
