/*
 * Copyright 2009 bufferings[at]gmail.com
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package bufferings.ktr.s3unit.env.factory;

import bufferings.ktr.s3unit.env.DevelopmentServerEnv;
import bufferings.ktr.s3unit.env.Env;
import bufferings.ktr.s3unit.env.NoServerEnv;
import bufferings.ktr.s3unit.env.ProductionServerEnv;
import bufferings.ktr.s3unit.util.ServerTypeChecker;
import bufferings.ktr.s3unit.util.ServerTypeChecker.ServerType;

/**
 * A class to create {@link Env} for the server type.
 * 
 * @author bufferings[at]gmail.com
 */
public class EnvFactory {

  /**
   * Creates {@link Env} for the server type.
   * 
   * @return created {@link Env}
   */
  public Env createEnv() {
    ServerType serverType = createServerTypeChecker().getServerType();
    switch (serverType) {
    case PRODUCTION_SERVER:
      return createProductionServerEnv();
    case DEVELOPMENT_SERVER:
      return createDevelopmentServerEnv();
    case NO_SERVER:
      return createNoServerEnv();
    default:
      throw new AssertionError("Unknown server type.");
    }
  }

  /**
   * Creates {@link ServerTypeChecker}
   * 
   * @return created {@link ServerTypeChecker}
   */
  protected ServerTypeChecker createServerTypeChecker() {
    return new ServerTypeChecker();
  }

  /**
   * Creates {@link Env} for the production server.
   * 
   * @return created {@link Env} for the production server
   */
  protected Env createProductionServerEnv() {
    return new ProductionServerEnv();
  }

  /**
   * Creates {@link Env} for the development server.
   * 
   * @return created {@link Env} for the development server
   */
  protected Env createDevelopmentServerEnv() {
    return new DevelopmentServerEnv();
  }

  /**
   * Creates {@link Env} for the no server tester.
   * 
   * @return created {@link Env} for the no server
   */
  protected Env createNoServerEnv() {
    return new NoServerEnv();
  }
}
