/*
 * Copyright 2009 bufferings[at]gmail.com
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package bufferings.ktr.s3unit.helper;

import com.google.appengine.api.datastore.DatastoreService;
import com.google.appengine.api.datastore.DatastoreServiceFactory;
import com.google.appengine.api.datastore.Query;

/**
 * A helper for datastore tests.
 * 
 * @author bufferings[at]gmail.com
 * @see org.slim3.tester.DatastoreTestCase
 */
public class DatastoreHelper {

  /**
   * a datastore service
   */
  protected DatastoreService ds;

  /**
   * Sets up before the Test method.
   */
  public void setUp() {
    ds = DatastoreServiceFactory.getDatastoreService();
  }

  /**
   * Tears down after the Test method.
   */
  public void tearDown() {
  }

  /**
   * Gets the datastore service.
   * 
   * @return ds the datastore service
   */
  public DatastoreService getDs() {
    return ds;
  }

  /**
   * Counts the number of the entity.
   * 
   * @param kind
   *          the kind
   * @return the number of the model
   */
  public int count(String kind) {
    return ds.prepare(new Query(kind)).countEntities();
  }
  
  /**
   * Counts the number of the model.
   * 
   * @param modelClass
   *            the model class
   * @return the number of the model
   */
  public int count(Class<?> modelClass) {
      return count(modelClass.getSimpleName());
  }
}
