/*
 * Copyright 2009 bufferings[at]gmail.com
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package bufferings.ktr.s3unit.helper;

import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slim3.tester.MockHttpServletRequest;
import org.slim3.tester.MockHttpServletResponse;
import org.slim3.tester.MockServletContext;
import org.slim3.util.RequestLocator;
import org.slim3.util.ResponseLocator;
import org.slim3.util.ServletContextLocator;

/**
 * A helper for servlet tests.
 * 
 * @author bufferings[at]gmail.com
 * 
 */
public class ServletHelper {

  /**
   * Previous {@link ServletContext}.
   */
  protected ServletContext prevApplication;

  /**
   * Previous {@link HttpServletRequest}.
   */
  protected HttpServletRequest prevRequest;

  /**
   * Previous {@link HttpServletResponse}.
   */
  protected HttpServletResponse prevResponse;

  /**
   * The mock for {@link ServletContext}.
   */
  protected MockServletContext application;

  /**
   * The mock for {@link HttpServletRequest}.
   */
  protected MockHttpServletRequest request;

  /**
   * The mock for {@link HttpServletResponse}.
   */
  protected MockHttpServletResponse response;

  /**
   * Sets up before the Test method.
   */
  public void setUp() {
    prevApplication = ServletContextLocator.get();
    prevRequest = RequestLocator.get();
    prevResponse = ResponseLocator.get();

    application = new MockServletContext();
    request = new MockHttpServletRequest(application);
    response = new MockHttpServletResponse();

    ServletContextLocator.set(application);
    RequestLocator.set(request);
    ResponseLocator.set(response);
  }

  /**
   * Tears down after the Test method.
   */
  public void tearDown() {
    application = null;
    request = null;
    response = null;

    ServletContextLocator.set(prevApplication);
    RequestLocator.set(prevRequest);
    ResponseLocator.set(prevResponse);
  }

  /**
   * Gets the mock for {@link ServletContext}.
   * 
   * @return the mock for {@link ServletContext}.
   */
  public MockServletContext getApplication() {
    return application;
  }

  /**
   * Gets the mock for {@link HttpServletRequest}.
   * 
   * @return the mock for {@link HttpServletRequest}.
   */
  public MockHttpServletRequest getRequest() {
    return request;
  }

  /**
   * Gets the mock for {@link HttpServletResponse}.
   * 
   * @return the mock for {@link HttpServletResponse}.
   */
  public MockHttpServletResponse getResponse() {
    return response;
  }

}
